==> tabular-data-column-widget-1.5.0-20141215.162730-110-sources.jar: org/gcube/portlets/user/td/columnwidget/client/ChangeColumnTypeDialog.java <==
package org.gcube.portlets.user.td.columnwidget.client;

import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;

import com.google.web.bindery.event.shared.EventBus;
import com.sencha.gxt.widget.core.client.Window;
import com.sencha.gxt.widget.core.client.event.SelectEvent;
import com.sencha.gxt.widget.core.client.event.SelectEvent.SelectHandler;
import com.sencha.gxt.widget.core.client.form.ComboBox;

/**
 * Dialog for Change Column Type 
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public class ChangeColumnTypeDialog extends Window {
	protected String WIDTH = "650px";
	protected String HEIGHT = "530px";
	protected TRId trId;
	
	protected String columnName=null;
	protected ComboBox<ColumnData> combo=null;
	
	public ChangeColumnTypeDialog(TRId trId, EventBus eventBus) {
		create(trId, null, eventBus);
	}

	public ChangeColumnTypeDialog(TRId trId, String columnName, EventBus eventBus) {
		create(trId, columnName, eventBus);
	}

	protected void create(TRId trId, String columnName, EventBus eventBus) {
		this.trId=trId;
		this.columnName=columnName;
		initWindow();
		ChangeColumnTypePanel changeColumnTypePanel= new ChangeColumnTypePanel(trId, columnName, eventBus);
		add(changeColumnTypePanel);
		
		
	}
	
	protected void initWindow() {
		setWidth(WIDTH);
		setHeight(HEIGHT);
		setBodyBorder(false);
		setResizable(false);
		setHeadingText("Change Column Type");
		//getHeader().setIcon(Resources.IMAGES.side_list());
	}
	
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	protected void initTools() {
		super.initTools();

		closeBtn.addSelectHandler(new SelectHandler() {

			public void onSelect(SelectEvent event) {
				close();
			}
		});

	}

	public void close() {
		hide();

	}
	
	
}

==> tabular-data-column-widget-1.8.0-20151001.115421-7-sources.jar: org/gcube/portlets/user/td/columnwidget/client/ChangeColumnTypeDialog.java <==
package org.gcube.portlets.user.td.columnwidget.client;

import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;

import com.google.web.bindery.event.shared.EventBus;
import com.sencha.gxt.widget.core.client.Window;
import com.sencha.gxt.widget.core.client.event.SelectEvent;
import com.sencha.gxt.widget.core.client.event.SelectEvent.SelectHandler;

/**
 * Dialog for Change Column Type
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 *
 */
public class ChangeColumnTypeDialog extends Window {
	private static final String WIDTH = "650px";
	private static final String HEIGHT = "530px";
	

	public ChangeColumnTypeDialog(TRId trId, EventBus eventBus) {
		create(trId, null, eventBus);
	}

	public ChangeColumnTypeDialog(TRId trId, String columnName,
			EventBus eventBus) {
		create(trId, columnName, eventBus);
	}

	protected void create(TRId trId, String columnName, EventBus eventBus) {
		initWindow();
		ChangeColumnTypePanel changeColumnTypePanel = new ChangeColumnTypePanel(
				trId, columnName, eventBus);
		add(changeColumnTypePanel);

	}

	protected void initWindow() {
		setWidth(WIDTH);
		setHeight(HEIGHT);
		setBodyBorder(false);
		setResizable(false);
		setHeadingText("Change Column Type");
		// getHeader().setIcon(Resources.IMAGES.side_list());
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected void initTools() {
		super.initTools();

		closeBtn.addSelectHandler(new SelectHandler() {

			public void onSelect(SelectEvent event) {
				close();
			}
		});

	}

	public void close() {
		hide();

	}

}
